@@ -25,6 +25,7 @@ OpenStack Client interface. Handles the REST calls and responses.
 # E0202: An attribute inherited from %s hide this method
 # pylint: disable=E0202
 
+import hashlib
 import logging
 import time
 
@@ -33,14 +34,15 @@ try:
 except ImportError:
     import json
 
+from oslo.utils import encodeutils
+from oslo.utils import importutils
 import requests
 
+from keystoneclient.openstack.common._i18n import _
 from keystoneclient.openstack.common.apiclient import exceptions
-from keystoneclient.openstack.common.gettextutils import _
-from keystoneclient.openstack.common import importutils
-
 
 _logger = logging.getLogger(__name__)
+SENSITIVE_HEADERS = ('X-Auth-Token', 'X-Subject-Token',)
 
 
 class HTTPClient(object):
@@ -98,6 +100,18 @@ class HTTPClient(object):
         self.http = http or requests.Session()
 
         self.cached_token = None
+        self.last_request_id = None
+
+    def _safe_header(self, name, value):
+        if name in SENSITIVE_HEADERS:
+            # because in python3 byte string handling is ... ug
+            v = value.encode('utf-8')
+            h = hashlib.sha1(v)
+            d = h.hexdigest()
+            return encodeutils.safe_decode(name), "{SHA1}%s" % d
+        else:
+            return (encodeutils.safe_decode(name),
+                    encodeutils.safe_decode(value))
 
     def _http_log_req(self, method, url, kwargs):
         if not self.debug:
@@ -110,7 +124,8 @@ class HTTPClient(object):
         ]
 
         for element in kwargs['headers']:
-            header = "-H '%s: %s'" % (element, kwargs['headers'][element])
+            header = ("-H '%s: %s'" %
+                      self._safe_header(element, kwargs['headers'][element]))
             string_parts.append(header)
 
         _logger.debug("REQ: %s" % " ".join(string_parts))
@@ -156,7 +171,7 @@ class HTTPClient(object):
              requests.Session.request (such as `headers`) or `json`
              that will be encoded as JSON and used as `data` argument
         """
-        kwargs.setdefault("headers", kwargs.get("headers", {}))
+        kwargs.setdefault("headers", {})
         kwargs["headers"]["User-Agent"] = self.user_agent
         if self.original_ip:
             kwargs["headers"]["Forwarded"] = "for=%s;by=%s" % (
@@ -177,6 +192,8 @@ class HTTPClient(object):
                                start_time, time.time()))
         self._http_log_resp(resp)
 
+        self.last_request_id = resp.headers.get('x-openstack-request-id')
+
         if resp.status_code >= 400:
             _logger.debug(
                 "Request returned failure status: %s",
@@ -247,6 +264,10 @@ class HTTPClient(object):
                 raise
             self.cached_token = None
             client.cached_endpoint = None
+            if self.auth_plugin.opts.get('token'):
+                self.auth_plugin.opts['token'] = None
+            if self.auth_plugin.opts.get('endpoint'):
+                self.auth_plugin.opts['endpoint'] = None
             self.authenticate()
             try:
                 token, endpoint = self.auth_plugin.token_and_endpoint(
@@ -323,6 +344,10 @@ class BaseClient(object):
         return self.http_client.client_request(
             self, method, url, **kwargs)
 
+    @property
+    def last_request_id(self):
+        return self.http_client.last_request_id
+
     def head(self, url, **kwargs):
         return self.client_request("HEAD", url, **kwargs)
 
