@@ -17,8 +17,7 @@
 """Super simple fake memcache client."""
 
 from oslo.config import cfg
-
-from keystoneclient.openstack.common import timeutils
+from oslo.utils import timeutils
 
 memcache_opts = [
     cfg.ListOpt('memcached_servers',
